<?php
/**
 *
 * Register Menus, Sidebars, Footer widgets
 *
 * @package Jakobian
 * @since Jakobian 1.0
 */

/**
    Menus & Navigation
**/

// Primary menu
function Jakobian_main_nav() {
  wp_nav_menu(array(
    'menu'              => __('Primary', 'jakobian'),
    'theme_location'    => 'primary',
    'container'         => false,
    'menu_class'        => 'nav navbar-nav',
    'fallback_cb'       => 'wp_bootstrap_navwalker::fallback',
    'walker'            => new wp_bootstrap_navwalker()
    ) 
  );
}

// Footer menu
function Jakobian_footer_nav() {
  wp_nav_menu(array(
    'menu'              => __('Footer Menu', 'jakobian'),
    'theme_location'    => 'footer-menu',
    'container'         => false,
    'menu_class'        => 'unstyled',
    'fallback_cb'       => 'wp_bootstrap_navwalker::fallback',
    'walker'            => new wp_bootstrap_navwalker()
    ) 
  );
}

//Secondary menu
function Jakobian_secondary_nav() {
  wp_nav_menu(array(
    'menu'              => __('Secondary Menu', 'jakobian'),
    'theme_location'    => 'secondary-menu',
    'container'         => false,
    'menu_class'        => 'nav navbar-nav',
    'fallback_cb'       => 'wp_bootstrap_navwalker::fallback',
    'walker'            => new wp_bootstrap_navwalker()
    ) 
  );
}


/**
    Add search box to Navigation menu
**/
function Jakobian_add_search_box($items, $args) {
    if($args->theme_location == 'primary' && ro_get_option('navbar_search') ) {
        $searchlink = '
        <li id="search_dropdown">
            <a href="#" class="dropdown-toggle" data-toggle="dropdown"><i class="fa fa-search" aria-hidden="true"></i></a>                 
            <ul id="dropdown_animation" class="dropdown-menu">
                <li>
                    <form class="navbar-form" role="search" action="'. esc_url( get_home_url( '/' ) ) . '">     
                        <div class="input-group">
                        <label for="nav-search" class="screen-reader-text">' . sprintf ( __('Search', 'jakobian') ) . '</label>
                            <input type="text" name="s" id="nav-search" class="search-pop form-control" value="" placeholder="' . sprintf (__('Search', 'jakobian') ) . '"/>
                            <span class="input-group-btn">
                                <button type="submit" class="btn btn-default pull-right"><i class="fa fa-search" aria-hidden="true"></i></button>
                            </span>
                        </div>
                    </form>
                </li>
            </ul>
        </li>';
        $items .= $searchlink;
    }
    return $items;
}
add_filter('wp_nav_menu_items', 'Jakobian_add_search_box', 10, 2);


/**
    Register widgetized area and update sidebar with default widgets
**/

function Jakobian_widgets_init() {

  // add sidebars
  register_sidebar( array(
    'name'          => __( 'Sidebar', 'jakobian' ),
    'id'            => 'sidebar',
    'description'   => __('The default sidebar, place widgets here will show in all posts', 'jakobian'),
    'before_widget' => '<div id="%1$s" class="widget %2$s">',
    'after_widget'  => '</div>',
    'before_title'  => '<h3 class="widget-title">',
    'after_title'   => '</h3>',
   ) );
  register_sidebar( array(
    'name'          => __( 'Pages Sidebar', 'jakobian' ),
    'id'            => 'sidebar-2',
    'description'   => __('The second sidebar, place widgets here will show in all pages','jakobian'),
    'before_widget' => '<div id="%1$s" class="widget %2$s">',
    'after_widget'  => '</div>',
    'before_title'  => '<h3 class="widget-title">',
    'after_title'   => '</h3>',
   ) ); 

  // add footer widgets
  switch (ro_get_option('footer_col')) {
    case '1':
    register_sidebar(array(
     'name'          => __( 'Footer Widget 1', 'jakobian' ),
     'id'            => 'footer-widget-1',
     'description'   => __('The first Row of Footer Widgets, place widgets as per no. of footer widgets setting you set in Theme Options', 'jakobian'),
     'before_widget' => '<article class="footer-widgets col-md-12 %2$s" id="%1$s">',
     'after_widget'  => '</article>',
     'before_title'  => '<h3 class="footer-widget-title">',
     'after_title'   => '</h3>',
     ) );
    break;

    case '2':
    register_sidebar(array(
     'name'          => __( 'Footer Widget 1', 'jakobian' ),
     'id'            => 'footer-widget-1',
     'description'   => __('The first Row of Footer Widgets, place widgets as per no. of footer widgets setting you set in Theme Options', 'jakobian'),
     'before_widget' => '<article class="footer-widgets col-md-6 %2$s" id="%1$s">',
     'after_widget'  => '</article>',
     'before_title'  => '<h3 class="footer-widget-title">',
     'after_title'   => '</h3>',
     ) );
    break;

    case '3':
    register_sidebar(array(
     'name'          => __( 'Footer Widget 1', 'jakobian' ),
     'id'            => 'footer-widget-1',
     'description'   => __('The first Row of Footer Widgets, place widgets as per no. of footer widgets setting you set in Theme Options', 'jakobian'),
     'before_widget' => '<article class="footer-widgets col-md-4 %2$s" id="%1$s">',
     'after_widget'  => '</article>',
     'before_title'  => '<h3 class="footer-widget-title">',
     'after_title'   => '</h3>',
     ) );
    break;

    case '4':
    register_sidebar(array(
     'name'          => __( 'Footer Widget 1', 'jakobian' ),
     'id'            => 'footer-widget-1',
     'description'   => __('The first Row of Footer Widgets, place widgets as per no. of footer widgets setting you set in Theme Options', 'jakobian'),
     'before_widget' => '<article class="footer-widgets col-md-3 %2$s" id="%1$s">',
     'after_widget'  => '</article>',
     'before_title'  => '<h3 class="footer-widget-title">',
     'after_title'   => '</h3>',
     ) );
    break;
  }

}

add_action( 'widgets_init', 'Jakobian_widgets_init' );